@@ -1,10 +1,67 @@
 
-#' Treat ... call argument as bquoted-values.
+
+build_minus_fn_env <- function(env) {
+  force(env)
+  orig_minus <- get('-', mode = 'function', envir = env)
+  minus_fn_to_name <- function(e1, e2) {
+    if(!missing(e2)) {
+      return(orig_minus(e1, e2))
+    }
+    if(is.name(e1)) {
+      return(e1)
+    }
+    if(is.character(e1) && (length(e1)==1)) {
+      return(as.name(e1))
+    }
+    orig_minus(e1)
+  }
+  env2 <- new.env(parent = env)
+  assign('-', minus_fn_to_name, envir = env2)
+  return(env2)
+}
+
+
+
+#' Near \code{eval(bquote(expr))} shortcut.
 #'
-#' bquote_call re-writes calls.
+#' Evaluate \code{expr} with \code{bquote} \code{.()} substitution.
+#' Including \code{.(-x)} promoting \code{x}'s value from character to a name,
+#' which is called "quote negation" (hence the minus-sign).
 #'
-#' Note: eagerly evalutes argument and writes them into the function's
-#' executing environment.
+#' @param expr expression to evaluate.
+#' @param where environment to work in.
+#' @return evaluated substituted expression.
+#'
+#' @examples
+#'
+#' if(requireNamespace('graphics', quietly = TRUE)) {
+#'    angle = 1:10
+#'    variable <- as.name("angle")
+#'    fn_name <- 'sin'
+#'    evalb(  plot(x = .(variable), y = .(-fn_name)(.(variable))) )
+#' }
+#'
+#' @export
+#'
+evalb <- function(expr, where = parent.frame()) {
+  force(where)
+  env2 <- build_minus_fn_env(where)
+  expr <- substitute(expr)  # can't set env, as that changes substitute's behavior
+  exprq <- do.call(bquote, list(expr, where = env2))
+  eval(exprq,
+       envir = env2,
+       enclos = env2)
+}
+
+
+
+
+#' Treat call argument as bquoted-values.
+#'
+#' Re-write call to evaluate \code{expr} with \code{bquote} \code{.()} substitution.
+#' Uses convetion that := is considered a alias for =.
+#' Including \code{.(-x)} promoting \code{x}'s value from character to a name,
+#' which is called "quote negation" (hence the minus-sign).
 #'
 #' @param call result of match.call()
 #' @param env environment to perform lookups in.
@@ -12,6 +69,7 @@
 #'
 #' @seealso \code{\link{bquote_function}}, \code{\link{bquote_call_args}}
 #'
+#' @keywords internal
 #'
 #' @export
 #'
@@ -19,7 +77,8 @@
 bquote_call <- function(call, env = parent.frame()) {
   force(env)
   # perform bquote transform
-  mc <- do.call(bquote, list(call, where = env), envir = env)
+  env2 <- build_minus_fn_env(env)
+  mc <- do.call(bquote, list(call, where = env2), envir = env2)
   # map a := b to name(a) = b
   fixpos <- which(vapply(mc[-1],
                          function(ai) {
@@ -49,9 +108,9 @@ bquote_call <- function(call, env = parent.frame()) {
 #'
 #' bquote_call_args is a helper to allow the user to write functions with bquote-enabled argument substitution.
 #' Uses convetion that := is considered a alias for =.
-#'
-#' Note: eagerly evalutes argument and writes them into the function's
-#' executing environment.
+#' Re-writes call args to evaluate \code{expr} with \code{bquote} \code{.()} substitution.
+#' Including \code{.(-x)} promoting \code{x}'s value from character to a name,
+#' which is called "quote negation" (hence the minus-sign).
 #'
 #' @param call result of match.call()
 #' @param env environment to perform lookups in.
@@ -59,6 +118,7 @@ bquote_call <- function(call, env = parent.frame()) {
 #'
 #' @seealso \code{\link{bquote_function}}
 #'
+#'
 #' @examples
 #'
 #' f <- function(q, ...) {
@@ -66,10 +126,6 @@ bquote_call <- function(call, env = parent.frame()) {
 #'   # match.call() best called in function context.
 #'   captured_call <- match.call()
 #'   captured_args <- bquote_call_args(captured_call, env)
-#'   for(nmi in setdiff(ls(),
-#'                      c("captured_call", "captured_args", "env"))) {
-#'     print(paste(nmi, get(nmi)))
-#'   }
 #'   captured_args
 #' }
 #'
@@ -77,12 +133,13 @@ bquote_call <- function(call, env = parent.frame()) {
 #' y <- 5
 #' qv <- 3
 #'
-#' # equivilent to f(3, x = 5)
-#' args <- f(q = .(qv), .(z) := .(y))
+#' # equivalent to f(3, x = 5)
+#' f(.(qv), .(z) := .(y))
 #'
-#' print(args)
+#' # equivalent to f(q = 7)
+#' qname <- 'q'
+#' f(.(qname) := 7)
 #'
-#' @keywords internal
 #'
 #' @export
 #'
@@ -105,7 +162,11 @@ bquote_call_args <- function(call, env = parent.frame()) {
 
 #' Adapt a function to use bquote on its arguments.
 #'
-#' bquote_function is for adapting a function defined elsewhere for bquite-enabled argument substitution.
+#' bquote_function is for adapting a function defined elsewhere for bquote-enabled argument substitution.
+#' Re-write call to evaluate \code{expr} with \code{bquote} \code{.()} substitution.
+#' Uses convetion that := is considered a alias for =.
+#' Including \code{.(-x)} promoting \code{x}'s value from character to a name,
+#' which is called "quote negation" (hence the minus-sign).
 #'
 #' @param fn function to adapt, must have non-empty formals().
 #' @return new function.
@@ -115,21 +176,21 @@ bquote_call_args <- function(call, env = parent.frame()) {
 #' @examples
 #'
 #'
-#'
-#' # angle = 1:10
-#' # variable <- as.name("angle")
-#' # plotb <- bquote_function(graphics::plot)
-#' # plotb(x = .(variable), y = sin(.(variable)))
+#' if(requireNamespace('graphics', quietly = TRUE)) {
+#'   angle = 1:10
+#'   variable <- as.name("angle")
+#'   plotb <- bquote_function(graphics::plot)
+#'   plotb(x = .(variable), y = sin(.(variable)))
+#' }
 #'
 #'
 #'
 #' f1 <- function(x) { substitute(x) }
 #' f2 <- bquote_function(f1)
-#' arg <- as.name("USER_ARG")
+#' arg <- "USER_ARG"
 #' f2(arg)    # returns arg
-#' f2(.(arg)) # returns USER_ARG
-#'
-#'
+#' f2(.(arg)) # returns "USER_ARG" (character)
+#' f2(.(-arg)) # returns USER_ARG (name)
 #'
 #'
 #' @export
@@ -160,25 +221,3 @@ bquote_function <- function(fn) {
   f
 }
 
-#' eval(bquote(expr)) shortcut.
-#'
-#' @param ... expression to evaluate (one argument).
-#' @param where environment to work in.
-#' @return eval(bquote(expr))
-#'
-#' @examples
-#'
-#' angle = 1:10
-#' variable <- as.name("angle")
-#' evalb(plot(x = .(variable), y = sin(.(variable))))
-#'
-#' @export
-#'
-evalb <- function(..., where = parent.frame()) {
-  force(where)
-  exprq <- bquote(..., where = where)
-  eval(exprq,
-       envir = where,
-       enclos = where)
-}
-
