@@ -12,9 +12,6 @@ sapply(1:4, l(x, x^2))
 ## ----fsqp---------------------------------------------------------------------
 1:4 %.>% { .^2 }
 
-## ----fnm----------------------------------------------------------------------
-(1:4) %.>% (x := { x^2 })(.)
-
 ## ----ft-----------------------------------------------------------------------
 l(x, y, x + 3*y)
 
